@@ -30,8 +30,8 @@ from . import ui_about  # pylint: disable=no-name-in-module
 
 # pylint: disable=too-few-public-methods
 class AboutDialog(ui_about.Ui_AboutDialog, QDialog):
-    def __init__(self):
-        super().__init__()
+    def __init__(self, parent=None):
+        super().__init__(parent)
 
         self.setupUi(self)
 
@@ -40,15 +40,13 @@ class AboutDialog(ui_about.Ui_AboutDialog, QDialog):
             self.release.setText(release_file.read())
 
         self.ok.clicked.connect(self.accept)
-        self.releaseNotes.clicked.connect(on_release_notes_clicked)
-        self.informationNotes.clicked.connect(on_information_notes_clicked)
+        self.releaseNotes.clicked.connect(self.on_release_notes_clicked)
+        self.informationNotes.clicked.connect(self.on_information_notes_clicked)
 
+    def on_release_notes_clicked(self):
+        release_notes_dialog = ReleaseNotesDialog(self)
+        release_notes_dialog.exec_()
 
-def on_release_notes_clicked():
-    release_notes_dialog = ReleaseNotesDialog()
-    release_notes_dialog.exec_()
-
-
-def on_information_notes_clicked():
-    information_notes_dialog = InformationNotesDialog()
-    information_notes_dialog.exec_()
+    def on_information_notes_clicked(self):
+        information_notes_dialog = InformationNotesDialog(self)
+        information_notes_dialog.exec_()
